@@ -22,6 +22,8 @@ if _TORCH_AVAILABLE:
     from flash.core.data.callback import FlashCallback
     from flash.core.data.data_module import DataModule  # noqa: E402
     from flash.core.data.data_source import DataSource
+    from flash.core.data.datasets import FlashDataset, FlashIterableDataset
+    from flash.core.data.input_transform import InputTransform
     from flash.core.data.process import Postprocess, Preprocess, Serializer
     from flash.core.model import Task  # noqa: E402
     from flash.core.trainer import Trainer  # noqa: E402
@@ -40,7 +42,10 @@ if _TORCH_AVAILABLE:
         "DataSource",
         "DataModule",
         "FlashCallback",
+        "FlashDataset",
+        "FlashIterableDataset",
         "Preprocess",
+        "InputTransform",
         "Postprocess",
         "Serializer",
         "Task",
