@@ -21,7 +21,6 @@ from torch.optim import Optimizer
 
 
 class NoFreeze(BaseFinetuning):
-
     def freeze_before_training(self, pl_module: LightningModule) -> None:
         pass
 
@@ -36,19 +35,16 @@ class NoFreeze(BaseFinetuning):
 
 
 class FlashBaseFinetuning(BaseFinetuning):
+    """FlashBaseFinetuning can be used to create a custom Flash Finetuning Callback.
+
+    Override :meth:`.finetune_function` to put your unfreeze logic.
+    """
 
     def __init__(self, attr_names: Union[str, List[str]] = "backbone", train_bn: bool = True):
-        r"""
-
-        FlashBaseFinetuning can be used to create a custom Flash Finetuning Callback.
-
-        Override ``finetune_function`` to put your unfreeze logic.
-
+        """
         Args:
             attr_names: Name(s) of the module attributes of the model to be frozen.
-
             train_bn: Whether to train Batch Norm layer
-
         """
         super().__init__()
 
@@ -70,7 +66,6 @@ class FlashBaseFinetuning(BaseFinetuning):
 
 
 class Freeze(FlashBaseFinetuning):
-
     def finetune_function(
         self,
         pl_module: LightningModule,
@@ -82,7 +77,6 @@ class Freeze(FlashBaseFinetuning):
 
 
 class FreezeUnfreeze(FlashBaseFinetuning):
-
     def __init__(self, attr_names: Union[str, List[str]] = "backbone", train_bn: bool = True, unfreeze_epoch: int = 10):
         super().__init__(attr_names, train_bn)
         self.unfreeze_epoch = unfreeze_epoch
@@ -105,13 +99,12 @@ class FreezeUnfreeze(FlashBaseFinetuning):
 
 
 class UnfreezeMilestones(FlashBaseFinetuning):
-
     def __init__(
         self,
         attr_names: Union[str, List[str]] = "backbone",
         train_bn: bool = True,
         unfreeze_milestones: tuple = (5, 10),
-        num_layers: int = 5
+        num_layers: int = 5,
     ):
         self.unfreeze_milestones = unfreeze_milestones
         self.num_layers = num_layers
@@ -129,7 +122,7 @@ class UnfreezeMilestones(FlashBaseFinetuning):
         if epoch == self.unfreeze_milestones[0]:
             # unfreeze num_layers last layers
             self.unfreeze_and_add_param_group(
-                modules=backbone_modules[-self.num_layers:],
+                modules=backbone_modules[-self.num_layers :],
                 optimizer=optimizer,
                 train_bn=self.train_bn,
             )
@@ -137,7 +130,7 @@ class UnfreezeMilestones(FlashBaseFinetuning):
         elif epoch == self.unfreeze_milestones[1]:
             # unfreeze remaining layers
             self.unfreeze_and_add_param_group(
-                modules=backbone_modules[:-self.num_layers],
+                modules=backbone_modules[: -self.num_layers],
                 optimizer=optimizer,
                 train_bn=self.train_bn,
             )
@@ -147,7 +140,7 @@ _DEFAULTS_FINETUNE_STRATEGIES = {
     "no_freeze": NoFreeze,
     "freeze": Freeze,
     "freeze_unfreeze": FreezeUnfreeze,
-    "unfreeze_milestones": UnfreezeMilestones
+    "unfreeze_milestones": UnfreezeMilestones,
 }
 
 
