@@ -12,21 +12,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 from types import FunctionType
-from typing import Any, Callable, Dict, List, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import Any, Dict, List, Optional, Tuple, Union
 
-import torch
+from pytorch_lightning.utilities.exceptions import MisconfigurationException
 from torch import nn
-from torch.optim.lr_scheduler import _LRScheduler
-from torchmetrics import Metric
 
-from flash.core.classification import ClassificationTask, Labels
-from flash.core.data.data_source import DefaultDataKeys
-from flash.core.data.process import Serializer
+from flash.core.classification import ClassificationAdapterTask, Labels
 from flash.core.registry import FlashRegistry
+from flash.core.utilities.types import LOSS_FN_TYPE, LR_SCHEDULER_TYPE, METRICS_TYPE, OPTIMIZER_TYPE, SERIALIZER_TYPE
+from flash.image.classification.adapters import TRAINING_STRATEGIES
 from flash.image.classification.backbones import IMAGE_CLASSIFIER_BACKBONES
 
 
-class ImageClassifier(ClassificationTask):
+class ImageClassifier(ClassificationAdapterTask):
     """The ``ImageClassifier`` is a :class:`~flash.Task` for classifying images. For more details, see
     :ref:`image_classification`. The ``ImageClassifier`` also supports multi-label classification with
     ``multi_label=True``. For more details, see :ref:`image_classification_multi_label`.
@@ -54,92 +52,93 @@ class ImageClassifier(ClassificationTask):
         pretrained: A bool or string to specify the pretrained weights of the backbone, defaults to ``True``
             which loads the default supervised pretrained weights.
         loss_fn: Loss function for training, defaults to :func:`torch.nn.functional.cross_entropy`.
-        optimizer: Optimizer to use for training, defaults to :class:`torch.optim.SGD`.
-        optimizer_kwargs: Additional kwargs to use when creating the optimizer (if not passed as an instance).
-        scheduler: The scheduler or scheduler class to use.
-        scheduler_kwargs: Additional kwargs to use when creating the scheduler (if not passed as an instance).
+        optimizer: Optimizer to use for training.
+        lr_scheduler: The LR scheduler to use during training.
         metrics: Metrics to compute for training and evaluation. Can either be an metric from the `torchmetrics`
             package, a custom metric inheriting from `torchmetrics.Metric`, a callable function or a list/dict
             containing a combination of the aforementioned. In all cases, each metric needs to have the signature
             `metric(preds,target)` and return a single scalar tensor. Defaults to :class:`torchmetrics.Accuracy`.
         learning_rate: Learning rate to use for training, defaults to ``1e-3``.
         multi_label: Whether the targets are multi-label or not.
-        serializer: The :class:`~flash.core.data.process.Serializer` to use when serializing prediction outputs.
+        serializer: A instance of :class:`~flash.core.data.process.Serializer` or a mapping consisting of such
+            to use when serializing prediction outputs.
+        training_strategy: string indicating the training strategy. Adjust if you want to use `learn2learn`
+            for doing meta-learning research
+        training_strategy_kwargs: Additional kwargs for setting the training strategy
     """
 
     backbones: FlashRegistry = IMAGE_CLASSIFIER_BACKBONES
+    training_strategies: FlashRegistry = TRAINING_STRATEGIES
 
     required_extras: str = "image"
 
     def __init__(
         self,
-        num_classes: int,
+        num_classes: Optional[int] = None,
         backbone: Union[str, Tuple[nn.Module, int]] = "resnet18",
         backbone_kwargs: Optional[Dict] = None,
         head: Optional[Union[FunctionType, nn.Module]] = None,
         pretrained: Union[bool, str] = True,
-        loss_fn: Optional[Callable] = None,
-        optimizer: Union[Type[torch.optim.Optimizer], torch.optim.Optimizer] = torch.optim.Adam,
-        optimizer_kwargs: Optional[Dict[str, Any]] = None,
-        scheduler: Optional[Union[Type[_LRScheduler], str, _LRScheduler]] = None,
-        scheduler_kwargs: Optional[Dict[str, Any]] = None,
-        metrics: Union[Metric, Callable, Mapping, Sequence, None] = None,
+        loss_fn: LOSS_FN_TYPE = None,
+        optimizer: OPTIMIZER_TYPE = "Adam",
+        lr_scheduler: LR_SCHEDULER_TYPE = None,
+        metrics: METRICS_TYPE = None,
         learning_rate: float = 1e-3,
         multi_label: bool = False,
-        serializer: Optional[Union[Serializer, Mapping[str, Serializer]]] = None,
+        serializer: SERIALIZER_TYPE = None,
+        training_strategy: Optional[str] = "default",
+        training_strategy_kwargs: Optional[Dict[str, Any]] = None,
     ):
-        super().__init__(
-            num_classes=num_classes,
-            model=None,
-            loss_fn=loss_fn,
-            optimizer=optimizer,
-            optimizer_kwargs=optimizer_kwargs,
-            scheduler=scheduler,
-            scheduler_kwargs=scheduler_kwargs,
-            metrics=metrics,
-            learning_rate=learning_rate,
-            multi_label=multi_label,
-            serializer=serializer or Labels(multi_label=multi_label),
-        )
 
         self.save_hyperparameters()
 
         if not backbone_kwargs:
             backbone_kwargs = {}
 
-        if isinstance(backbone, tuple):
-            self.backbone, num_features = backbone
+        if not training_strategy_kwargs:
+            training_strategy_kwargs = {}
+
+        if training_strategy == "default":
+            if not num_classes:
+                raise MisconfigurationException("`num_classes` should be provided.")
         else:
-            self.backbone, num_features = self.backbones.get(backbone)(pretrained=pretrained, **backbone_kwargs)
+            num_classes = training_strategy_kwargs.get("ways", None)
+            if not num_classes:
+                raise MisconfigurationException(
+                    "`training_strategy_kwargs` should contain `ways`, `meta_batch_size` and `shots`."
+                )
+
+        if isinstance(backbone, tuple):
+            backbone, num_features = backbone
+        else:
+            backbone, num_features = self.backbones.get(backbone)(pretrained=pretrained, **backbone_kwargs)
 
         head = head(num_features, num_classes) if isinstance(head, FunctionType) else head
-        self.head = head or nn.Sequential(
+        head = head or nn.Sequential(
             nn.Linear(num_features, num_classes),
         )
 
-    def training_step(self, batch: Any, batch_idx: int) -> Any:
-        batch = (batch[DefaultDataKeys.INPUT], batch[DefaultDataKeys.TARGET])
-        return super().training_step(batch, batch_idx)
-
-    def validation_step(self, batch: Any, batch_idx: int) -> Any:
-        batch = (batch[DefaultDataKeys.INPUT], batch[DefaultDataKeys.TARGET])
-        return super().validation_step(batch, batch_idx)
-
-    def test_step(self, batch: Any, batch_idx: int) -> Any:
-        batch = (batch[DefaultDataKeys.INPUT], batch[DefaultDataKeys.TARGET])
-        return super().test_step(batch, batch_idx)
-
-    def predict_step(self, batch: Any, batch_idx: int, dataloader_idx: int = 0) -> Any:
-        batch[DefaultDataKeys.PREDS] = super().predict_step(
-            (batch[DefaultDataKeys.INPUT]), batch_idx, dataloader_idx=dataloader_idx
+        adapter_from_class = self.training_strategies.get(training_strategy)
+        adapter = adapter_from_class(
+            task=self,
+            num_classes=num_classes,
+            backbone=backbone,
+            head=head,
+            pretrained=pretrained,
+            **training_strategy_kwargs,
         )
-        return batch
 
-    def forward(self, x) -> torch.Tensor:
-        x = self.backbone(x)
-        if x.dim() == 4:
-            x = x.mean(-1).mean(-1)
-        return self.head(x)
+        super().__init__(
+            adapter,
+            num_classes=num_classes,
+            loss_fn=loss_fn,
+            metrics=metrics,
+            learning_rate=learning_rate,
+            optimizer=optimizer,
+            lr_scheduler=lr_scheduler,
+            multi_label=multi_label,
+            serializer=serializer or Labels(multi_label=multi_label),
+        )
 
     @classmethod
     def available_pretrained_weights(cls, backbone: str):
