@@ -15,8 +15,8 @@ from typing import Any, Callable, Dict, Optional, Tuple
 
 from flash.core.data.callback import BaseDataFetcher
 from flash.core.data.data_module import DataModule
-from flash.core.data.data_source import DefaultDataSources
-from flash.core.data.process import Preprocess
+from flash.core.data.data_source import DefaultDataKeys, DefaultDataSources
+from flash.core.data.process import Postprocess, Preprocess
 from flash.core.integrations.icevision.data import IceVisionParserDataSource, IceVisionPathsDataSource
 from flash.core.integrations.icevision.transforms import default_transforms
 from flash.core.utilities.imports import _ICEVISION_AVAILABLE
@@ -70,9 +70,16 @@ class InstanceSegmentationPreprocess(Preprocess):
         return default_transforms(self.image_size)
 
 
+class InstanceSegmentationPostProcess(Postprocess):
+    @staticmethod
+    def uncollate(batch: Any) -> Any:
+        return batch[DefaultDataKeys.PREDS]
+
+
 class InstanceSegmentationData(DataModule):
 
     preprocess_cls = InstanceSegmentationPreprocess
+    postprocess_cls = InstanceSegmentationPostProcess
 
     @classmethod
     def from_coco(
@@ -92,7 +99,7 @@ class InstanceSegmentationData(DataModule):
         preprocess: Optional[Preprocess] = None,
         val_split: Optional[float] = None,
         batch_size: int = 4,
-        num_workers: Optional[int] = None,
+        num_workers: int = 0,
         **preprocess_kwargs: Any,
     ):
         """Creates a :class:`~flash.image.instance_segmentation.data.InstanceSegmentationData` object from the
@@ -171,7 +178,7 @@ class InstanceSegmentationData(DataModule):
         preprocess: Optional[Preprocess] = None,
         val_split: Optional[float] = None,
         batch_size: int = 4,
-        num_workers: Optional[int] = None,
+        num_workers: int = 0,
         **preprocess_kwargs: Any,
     ):
         """Creates a :class:`~flash.image.instance_segmentation.data.InstanceSegmentationData` object from the
