@@ -11,17 +11,16 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import Any, cast, Dict, List, Mapping, NoReturn, Optional, Sequence, Tuple, Type, Union
+from typing import Any, cast, List, NoReturn, Optional, Sequence, Tuple, Union
 
 import torch
 from torch import nn
-from torch.optim.lr_scheduler import _LRScheduler
 
 from flash.core.data.data_source import DefaultDataKeys
-from flash.core.data.process import Serializer
 from flash.core.model import Task
 from flash.core.registry import FlashRegistry
 from flash.core.utilities.imports import _IMAGE_AVAILABLE
+from flash.core.utilities.types import LR_SCHEDULER_TYPE, OPTIMIZER_TYPE, SERIALIZER_TYPE
 from flash.image.style_transfer import STYLE_TRANSFER_BACKBONES
 
 if _IMAGE_AVAILABLE:
@@ -58,10 +57,9 @@ class StyleTransfer(Task):
         content_layer: Which layer from the backbone to extract the content loss from.
         content_weight: The weight associated with the content loss. A lower value will lose content over style.
         style_layers: Layers from the backbone to derive the style loss from.
-        optimizer: Optimizer to use for training the model.
-        optimizer_kwargs: Optimizer keywords arguments.
-        scheduler: Scheduler to use for training the model.
-        scheduler_kwargs: Scheduler keywords arguments.
+        style_weight: The weight associated with the style loss. A lower value will lose style over content.
+        optimizer: Optimizer to use for training.
+        lr_scheduler: The LR scheduler to use during training.
         learning_rate: Learning rate to use for training, defaults to ``1e-3``.
         serializer: The :class:`~flash.core.data.process.Serializer` to use when serializing prediction outputs.
     """
@@ -79,12 +77,10 @@ class StyleTransfer(Task):
         content_weight: float = 1e5,
         style_layers: Union[Sequence[str], str] = ["relu1_2", "relu2_2", "relu3_3", "relu4_3"],
         style_weight: float = 1e10,
-        optimizer: Union[Type[torch.optim.Optimizer], torch.optim.Optimizer] = torch.optim.Adam,
-        optimizer_kwargs: Optional[Dict[str, Any]] = None,
-        scheduler: Optional[Union[Type[_LRScheduler], str, _LRScheduler]] = None,
-        scheduler_kwargs: Optional[Dict[str, Any]] = None,
+        optimizer: OPTIMIZER_TYPE = "Adam",
+        lr_scheduler: LR_SCHEDULER_TYPE = None,
         learning_rate: float = 1e-3,
-        serializer: Optional[Union[Serializer, Mapping[str, Serializer]]] = None,
+        serializer: SERIALIZER_TYPE = None,
     ):
         self.save_hyperparameters(ignore="style_image")
 
@@ -112,9 +108,7 @@ class StyleTransfer(Task):
             model=model,
             loss_fn=perceptual_loss,
             optimizer=optimizer,
-            optimizer_kwargs=optimizer_kwargs,
-            scheduler=scheduler,
-            scheduler_kwargs=scheduler_kwargs,
+            lr_scheduler=lr_scheduler,
             learning_rate=learning_rate,
             serializer=serializer,
         )
